==> lori_sdk-0.4.8%2B1.tar.gz: lib/data/api/sales/sales_marketing_api.dart <==
import 'dart:math';

import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:lori_sdk/data/database/interfaces/userDao.dart';
import 'package:lori_sdk/data/lori_api.dart';
import 'package:lori_sdk/data/models/banner.dart';
import 'package:lori_sdk/data/models/product/product.dart';
import 'package:lori_sdk/data/models/ranking/dealer.dart';
import 'package:lori_sdk/data/models/ranking/dealerRanking.dart';
import 'package:lori_sdk/data/models/user.dart';
import 'package:lori_sdk/data/models/user_promotions/userPromotion.dart';

class SalesMarketingApi {
  static const GET_DEALER_BY_CPF = "sales/marketing/dealer/searchByCpf/document";
  static const GET_DEALER_RANKING_FOR_DEALER = "sales/marketing/dealer/ranking/individual/%";

  static const GET_BANNERS = "sales/marketing/banners";

  static const GET_FAVORITES = "sales/marketing/buyers/favorites";

  static const GET_USER_PROMOTIONS = "sales/marketing/buyers/promotions";
  static const ACTIVATE_USER_PROMOTION = "sales/marketing/buyers/promotions/active";


  Dio _requester;

  SalesMarketingApi({@required Dio requester}) : this._requester = requester;


  ///
  /// region Dealers
  ///

  Future<ApiCallback<void>> getDealer() async {
    var loggedUser = await UserDao().get();

    if (loggedUser == null) {
      return ApiCallback(isSuccessful: false);
    }

    try {
      Map<String, dynamic> queryParameters = {
        'cpf': loggedUser.cpf
      };
      var response = await _requester.get(GET_DEALER_BY_CPF,
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));

      if (response.data.toString().isNotEmpty) {
        var dealer = Dealer.fromJson(response.data);

        loggedUser.dealer = dealer;

        await UserDao().update(loggedUser);

        return ApiCallback(isSuccessful: true);
      }
      else {
        return ApiCallback(isSuccessful: false);
      }

    }
    catch (e) {
      return ApiCallback().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<DealerRanking>> getDealerRanking({int month, int year, bool isPerStore = false}) async {
    var loggedUser = await UserDao().get();

    if (loggedUser == null || loggedUser.dealer == null) {
      return ApiCallback(isSuccessful: false);
    }

    if (month == null || year == null) {
      final now = DateTime.now();
      month = now.month;
      year = now.year;
    }

    try {
      Map<String, dynamic> queryParameters = {
        'period': "$month/$year",
        'isPerStore': isPerStore
      };
      var response = await _requester.get(GET_DEALER_RANKING_FOR_DEALER.replaceAll('%', loggedUser.dealer.id),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));

      var dealerRanking = DealerRanking.fromJson(response.data);

      return ApiCallback(isSuccessful: true, resultData: dealerRanking);
    }
    catch (e) {
      return ApiCallback().defaultErrorCallback(e);
    }
  }


  ///
  /// endregion
  ///

  ///
  /// region Banners
  ///

  /// Retrieve all banners for the user
  Future<ApiCallback<List<Banner>>> getBanners({BannerType type = BannerType.carousel}) async {
    try {
      Map<String, dynamic> queryParameters = {
        'type': type.index
      };
      var response = await _requester.get(GET_BANNERS,
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var banners = List<Banner>();
      for (var row in responseData) {
        banners.add(Banner.fromJson(row));
      }
      return ApiCallback<List<Banner>>(isSuccessful: true, resultData: banners);
    } on DioError catch (e) {
      return ApiCallback<List<Banner>>().defaultErrorCallback(e);
    }
  }

  ///
  /// endregion
  ///

  ///
  /// region Favorites
  ///

  /// Retrieve all products favorited by the user
  Future<ApiCallback<List<Product>>> getFavoriteProducts() async {
    try {
      var response = await _requester.get(GET_FAVORITES,
          options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var products = List<Product>();
      for (var row in responseData) {
        products.add(Product.fromJson(row));
      }
      return ApiCallback<List<Product>>(
          isSuccessful: true, resultData: products);
    } on DioError catch (e) {
      return ApiCallback<List<Product>>().defaultErrorCallback(e);
    }
  }

  ///
  /// endregion
  ///


  ///
  /// region User Promotions
  ///

  /// Load all users promotions for the current user.
  Future<ApiCallback<List<UserPromotion>>> getUserPromotions() async {
    try {
      var response = await _requester.get(
          GET_USER_PROMOTIONS,
          options: Options(responseType: ResponseType.json)
      );
      var responseData = response.data as List;
      var promotions = List<UserPromotion>();
      for (var row in responseData) {
        promotions.add(UserPromotion.fromJson(row));
      }
      // Callback invocation
      return ApiCallback<List<UserPromotion>>(isSuccessful: true, resultData: promotions);
    } on DioError catch (e) {
      return ApiCallback<List<UserPromotion>>().defaultErrorCallback(e);
    }
  }

  /// Activate a promotion for the current user give it's id.
  Future<ApiCallback<void>> activateUserPromotion(String externalId) async {
    try {
      Map<String, String> body = {
        "partnerPromotionId": externalId,
      };
      await _requester.post(
          ACTIVATE_USER_PROMOTION,
          queryParameters: body,
          options: Options(responseType: ResponseType.json));
      // Callback invocation
      return ApiCallback<void>(isSuccessful: true);
    } on DioError catch (e) {
      return ApiCallback<void>().defaultErrorCallback(e);
    }
  }

  ///
  /// User Promotions part. All methods related to User Promotions module.
  /// endregion
  ///
}

==> lori_sdk-0.5.9%2B1.tar.gz: lib/data/api/sales/sales_marketing_api.dart <==
import 'dart:ffi';
import 'dart:math';

import 'dart:async';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';
import 'package:lori_sdk/data/database/interfaces/userDao.dart';
import 'package:lori_sdk/data/lori_api.dart';
import 'package:lori_sdk/data/models/banner.dart';
import 'package:lori_sdk/data/models/product/favoriteProduct.dart';
import 'package:lori_sdk/data/models/product/product.dart';
import 'package:lori_sdk/data/models/ranking/dealer.dart';
import 'package:lori_sdk/data/models/ranking/dealerRanking.dart';
import 'package:lori_sdk/data/models/tutorial.dart';
import 'package:lori_sdk/data/models/user.dart';
import 'package:lori_sdk/data/models/user_promotions/userPromotion.dart';

class SalesMarketingApi {
  static const GET_TUTORIALS = "sales/marketing/tutorials";

  static const GET_DEALER_BY_CPF =
      "sales/marketing/dealer/searchByCpf/document";
  static const GET_DEALER_RANKING_FOR_DEALER =
      "sales/marketing/dealer/ranking/individual/%";

  static const GET_BANNERS = "sales/marketing/banners";

  static const GET_FAVORITES = "sales/marketing/buyers/favorites";
  static const PRODUCT_FAVORITE = "sales/marketing/buyers/favorites/%";

  static const GET_USER_PROMOTIONS = "sales/marketing/buyers/promotions";
  static const ACTIVATE_USER_PROMOTION =
      "sales/marketing/buyers/promotions/active";

  Dio _requester;

  SalesMarketingApi({@required Dio requester}) : this._requester = requester;

  ///
  /// region Tutorials
  ///

  Future<ApiCallback<Tutorial>> getTutorial() async {
    try {
      var response = await _requester.get(GET_TUTORIALS,
          options: Options(responseType: ResponseType.json));
      if (response.data == null || response.data.toString().isEmpty) {
        return ApiCallback<Tutorial>(isSuccessful: true);
      } else {
        var tutorial = Tutorial.fromJson(response.data);
        tutorial.pages.sort((lp, rp) => lp.order.compareTo(rp.order));
        return ApiCallback<Tutorial>(isSuccessful: true, resultData: tutorial);
      }
    } on DioError catch (e) {
      return ApiCallback<Tutorial>(isSuccessful: true);
    }
  }

  ///
  /// endregion
  ///

  ///
  /// region Dealers
  ///

  Future<ApiCallback<void>> getDealer() async {
    var loggedUser = await UserDao().get();

    if (loggedUser == null) {
      return ApiCallback(isSuccessful: false);
    }

    try {
      Map<String, dynamic> queryParameters = {'cpf': loggedUser.cpf};
      var response = await _requester.get(GET_DEALER_BY_CPF,
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));

      if (response.data.toString().isNotEmpty) {
        var dealer = Dealer.fromJson(response.data);

        loggedUser.dealer = dealer;

        await UserDao().update(loggedUser);

        return ApiCallback(isSuccessful: true);
      } else {
        return ApiCallback(isSuccessful: false);
      }
    } catch (e) {
      return ApiCallback().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<DealerRanking>> getDealerRanking(
      {int month, int year, bool isPerStore = false}) async {
    var loggedUser = await UserDao().get();

    if (loggedUser == null || loggedUser.dealer == null) {
      return ApiCallback(isSuccessful: false);
    }

    if (month == null || year == null) {
      final now = DateTime.now();
      month = now.month;
      year = now.year;
    }

    try {
      Map<String, dynamic> queryParameters = {
        'period': "$month/$year",
        'isPerStore': isPerStore
      };
      var response = await _requester.get(
          GET_DEALER_RANKING_FOR_DEALER.replaceAll('%', loggedUser.dealer.id),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));

      var dealerRanking = DealerRanking.fromJson(response.data);

      return ApiCallback(isSuccessful: true, resultData: dealerRanking);
    } catch (e) {
      return ApiCallback<DealerRanking>().defaultErrorCallback(e);
    }
  }

  ///
  /// endregion
  ///

  ///
  /// region Banners
  ///

  /// Retrieve all banners for the user
  Future<ApiCallback<List<Banner>>> getBanners(
      {BannerType type = BannerType.carousel}) async {
    try {
      Map<String, dynamic> queryParameters = {'type': type.index};
      var response = await _requester.get(GET_BANNERS,
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var banners = List<Banner>();
      for (var row in responseData) {
        banners.add(Banner.fromJson(row));
      }
      return ApiCallback<List<Banner>>(isSuccessful: true, resultData: banners);
    } on DioError catch (e) {
      return ApiCallback<List<Banner>>().defaultErrorCallback(e);
    }
  }

  ///
  /// endregion
  ///

  ///
  /// region Favorites
  ///

  /// Retrieve all products favorited by the user
  Future<ApiCallback<List<Product>>> getFavoriteProducts() async {
    try {
      var response = await _requester.get(GET_FAVORITES,
          options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var products = List<Product>();
      for (var row in responseData) {
        products.add(Product.fromJson(row));
      }
      return ApiCallback<List<Product>>(
          isSuccessful: true, resultData: products);
    } on DioError catch (e) {
      return ApiCallback<List<Product>>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<FavoriteProduct>> getIsProductFavorite(
      String productId) async {
    try {
      var response = await _requester.get(
          PRODUCT_FAVORITE.replaceAll("%", productId),
          options: Options(responseType: ResponseType.json));
      var isfavorite = FavoriteProduct.fromJson(response.data);
      return ApiCallback<FavoriteProduct>(
          isSuccessful: true, resultData: isfavorite);
    } on DioError catch (e) {
      return ApiCallback<FavoriteProduct>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<void>> postProductFavorite(String productId) async {
    try {
      await _requester.post(PRODUCT_FAVORITE.replaceAll("%", productId),
          options: Options(responseType: ResponseType.json));
      return ApiCallback<void>(isSuccessful: true);
    } on DioError catch (e) {
      return ApiCallback<void>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<void>> deleteProductFavorite(String productId) async {
    try {
      await _requester.delete(PRODUCT_FAVORITE.replaceAll("%", productId),
          options: Options(responseType: ResponseType.json));
      return ApiCallback<void>(isSuccessful: true);
    } on DioError catch (e) {
      return ApiCallback<void>().defaultErrorCallback(e);
    }
  }

  ///
  /// endregion
  ///

  ///
  /// region User Promotions
  ///

  /// Load all users promotions for the current user.
  Future<ApiCallback<List<UserPromotion>>> getUserPromotions() async {
    try {
      var response = await _requester.get(GET_USER_PROMOTIONS,
          options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var promotions = List<UserPromotion>();
      for (var row in responseData) {
        promotions.add(UserPromotion.fromJson(row));
      }
      // Callback invocation
      return ApiCallback<List<UserPromotion>>(
          isSuccessful: true, resultData: promotions);
    } on DioError catch (e) {
      return ApiCallback<List<UserPromotion>>().defaultErrorCallback(e);
    }
  }

  /// Activate a promotion for the current user give it's id.
  Future<ApiCallback<void>> activateUserPromotion(String externalId) async {
    try {
      Map<String, String> body = {
        "partnerPromotionId": externalId,
      };
      await _requester.post(ACTIVATE_USER_PROMOTION,
          queryParameters: body,
          options: Options(responseType: ResponseType.json));
      // Callback invocation
      return ApiCallback<void>(isSuccessful: true);
    } on DioError catch (e) {
      return ApiCallback<void>().defaultErrorCallback(e);
    }
  }
}

///
/// User Promotions part. All methods related to User Promotions module.
/// endregion
//
